==> pari_2.5.5.orig.tar.gz: pari-2.5.5/src/kernel/none/tune-gen.h <==
#ifdef PARI_TUNE
long SQRI_FFT_LIMIT           = __SQRI_FFT_LIMIT;
long MULII_FFT_LIMIT           = __MULII_FFT_LIMIT;
long SQRI_KARATSUBA_LIMIT     = __SQRI_KARATSUBA_LIMIT;
long MULII_KARATSUBA_LIMIT     = __MULII_KARATSUBA_LIMIT;
long MULRR_MULII_LIMIT     = __MULRR_MULII_LIMIT;
long Fp_POW_REDC_LIMIT        = __Fp_POW_REDC_LIMIT;
long Fp_POW_BARRETT_LIMIT     = __Fp_POW_BARRETT_LIMIT;
long INVMOD_GMP_LIMIT         = __INVMOD_GMP_LIMIT;
long DIVRR_GMP_LIMIT          = __DIVRR_GMP_LIMIT;
long Flx_MUL_KARATSUBA_LIMIT  = __Flx_MUL_KARATSUBA_LIMIT;
long Flx_SQR_KARATSUBA_LIMIT  = __Flx_SQR_KARATSUBA_LIMIT;
long Flx_MUL_HALFMULII_LIMIT  = __Flx_MUL_HALFMULII_LIMIT;
long Flx_SQR_HALFSQRI_LIMIT   = __Flx_SQR_HALFSQRI_LIMIT;
long Flx_MUL_MULII_LIMIT      = __Flx_MUL_MULII_LIMIT;
long Flx_SQR_SQRI_LIMIT       = __Flx_SQR_SQRI_LIMIT;
long Flx_MUL_MULII2_LIMIT     = __Flx_MUL_MULII2_LIMIT;
long Flx_SQR_SQRI2_LIMIT      = __Flx_SQR_SQRI2_LIMIT;
long Flx_INVMONTGOMERY_LIMIT  = __Flx_INVMONTGOMERY_LIMIT;
long Flx_REM_MONTGOMERY_LIMIT = __Flx_REM_MONTGOMERY_LIMIT;
long Flx_POW_MONTGOMERY_LIMIT = __Flx_POW_MONTGOMERY_LIMIT;
long Flx_HALFGCD_LIMIT        = __Flx_HALFGCD_LIMIT;
long Flx_GCD_LIMIT            = __Flx_GCD_LIMIT;
long Flx_EXTGCD_LIMIT         = __Flx_EXTGCD_LIMIT;
long FpX_INVMONTGOMERY_LIMIT  = __FpX_INVMONTGOMERY_LIMIT;
long FpX_REM_MONTGOMERY_LIMIT = __FpX_REM_MONTGOMERY_LIMIT;
long FpX_POW_MONTGOMERY_LIMIT = __FpX_POW_MONTGOMERY_LIMIT;
long FpX_HALFGCD_LIMIT        = __FpX_HALFGCD_LIMIT;
long FpX_GCD_LIMIT            = __FpX_GCD_LIMIT;
long FpX_EXTGCD_LIMIT         = __FpX_EXTGCD_LIMIT;
long EXPNEWTON_LIMIT          = __EXPNEWTON_LIMIT;
long INVNEWTON_LIMIT          = __INVNEWTON_LIMIT;
long LOGAGM_LIMIT             = __LOGAGM_LIMIT;
long LOGAGMCX_LIMIT           = __LOGAGMCX_LIMIT;
long AGM_ATAN_LIMIT           = __AGM_ATAN_LIMIT;
long RgX_SQR_LIMIT            = __RgX_SQR_LIMIT;
long RgX_MUL_LIMIT            = __RgX_MUL_LIMIT;
#endif

==> pari_2.7.5.orig.tar.gz: pari-2.7.5/src/kernel/none/tune-gen.h <==
#ifdef PARI_TUNE
long SQRI_FFT_LIMIT           = __SQRI_FFT_LIMIT;
long MULII_FFT_LIMIT          = __MULII_FFT_LIMIT;
long SQRI_KARATSUBA_LIMIT     = __SQRI_KARATSUBA_LIMIT;
long MULII_KARATSUBA_LIMIT    = __MULII_KARATSUBA_LIMIT;
long MULRR_MULII_LIMIT        = __MULRR_MULII_LIMIT;
long Fp_POW_REDC_LIMIT        = __Fp_POW_REDC_LIMIT;
long Fp_POW_BARRETT_LIMIT     = __Fp_POW_BARRETT_LIMIT;
long INVMOD_GMP_LIMIT         = __INVMOD_GMP_LIMIT;
long DIVRR_GMP_LIMIT          = __DIVRR_GMP_LIMIT;
long Flx_MUL_KARATSUBA_LIMIT  = __Flx_MUL_KARATSUBA_LIMIT;
long Flx_SQR_KARATSUBA_LIMIT  = __Flx_SQR_KARATSUBA_LIMIT;
long Flx_MUL_HALFMULII_LIMIT  = __Flx_MUL_HALFMULII_LIMIT;
long Flx_SQR_HALFSQRI_LIMIT   = __Flx_SQR_HALFSQRI_LIMIT;
long Flx_MUL_MULII_LIMIT      = __Flx_MUL_MULII_LIMIT;
long Flx_SQR_SQRI_LIMIT       = __Flx_SQR_SQRI_LIMIT;
long Flx_MUL_MULII2_LIMIT     = __Flx_MUL_MULII2_LIMIT;
long Flx_SQR_SQRI2_LIMIT      = __Flx_SQR_SQRI2_LIMIT;
long Flx_INVBARRETT_LIMIT     = __Flx_INVBARRETT_LIMIT;
long Flx_DIVREM_BARRETT_LIMIT = __Flx_DIVREM_BARRETT_LIMIT;
long Flx_REM_BARRETT_LIMIT    = __Flx_REM_BARRETT_LIMIT;
long Flx_BARRETT_LIMIT        = __Flx_BARRETT_LIMIT;
long Flx_HALFGCD_LIMIT        = __Flx_HALFGCD_LIMIT;
long Flx_GCD_LIMIT            = __Flx_GCD_LIMIT;
long Flx_EXTGCD_LIMIT         = __Flx_EXTGCD_LIMIT;
long FpX_INVBARRETT_LIMIT     = __FpX_INVBARRETT_LIMIT;
long FpX_DIVREM_BARRETT_LIMIT = __FpX_DIVREM_BARRETT_LIMIT;
long FpX_REM_BARRETT_LIMIT    = __FpX_REM_BARRETT_LIMIT;
long FpX_BARRETT_LIMIT        = __FpX_BARRETT_LIMIT;
long FpX_HALFGCD_LIMIT        = __FpX_HALFGCD_LIMIT;
long FpX_GCD_LIMIT            = __FpX_GCD_LIMIT;
long FpX_EXTGCD_LIMIT         = __FpX_EXTGCD_LIMIT;
long EXPNEWTON_LIMIT          = __EXPNEWTON_LIMIT;
long INVNEWTON_LIMIT          = __INVNEWTON_LIMIT;
long LOGAGM_LIMIT             = __LOGAGM_LIMIT;
long LOGAGMCX_LIMIT           = __LOGAGMCX_LIMIT;
long AGM_ATAN_LIMIT           = __AGM_ATAN_LIMIT;
long RgX_SQR_LIMIT            = __RgX_SQR_LIMIT;
long RgX_MUL_LIMIT            = __RgX_MUL_LIMIT;
#endif
